# mypy-boto3-appstream

[![PyPI - mypy-boto3-appstream](https://img.shields.io/pypi/v/mypy-boto3-appstream.svg?color=blue)](https://pypi.org/project/mypy-boto3-appstream)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-appstream.svg?color=blue)](https://pypi.org/project/mypy-boto3-appstream)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.AppStream 1.14.41](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/appstream.html#AppStream) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `AppStream` service.

```bash
python -m pip install boto3-stubs[appstream]
```

## How to use

### Client annotations

`AppStreamClient` provides annotations for `boto3.client("appstream")`.

```python
import boto3

from mypy_boto3_appstream import AppStreamClient
from mypy_boto3_appstream.paginator import (
    DescribeDirectoryConfigsPaginator,
    DescribeFleetsPaginator,
    DescribeImageBuildersPaginator,
    DescribeImagesPaginator,
    DescribeSessionsPaginator,
    DescribeStacksPaginator,
    DescribeUsersPaginator,
    DescribeUserStackAssociationsPaginator,
    ListAssociatedFleetsPaginator,
    ListAssociatedStacksPaginator,
)
from mypy_boto3_appstream.type_defs import AccessEndpointTypeDef, ...
from mypy_boto3_appstream.waiter import FleetStartedWaiter, FleetStoppedWaiter

client: AppStreamClient = boto3.client("appstream")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: AppStreamClient = session.client("appstream")
```

### Paginators annotations

`mypy_boto3_appstream.paginator` module contains type annotations for all paginators.

```python

client: AppStreamClient = boto3.client("appstream")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
describe_directory_configs_paginator: DescribeDirectoryConfigsPaginator = client.get_paginator("describe_directory_configs")
describe_fleets_paginator: DescribeFleetsPaginator = client.get_paginator("describe_fleets")
describe_image_builders_paginator: DescribeImageBuildersPaginator = client.get_paginator("describe_image_builders")
describe_images_paginator: DescribeImagesPaginator = client.get_paginator("describe_images")
describe_sessions_paginator: DescribeSessionsPaginator = client.get_paginator("describe_sessions")
describe_stacks_paginator: DescribeStacksPaginator = client.get_paginator("describe_stacks")
describe_user_stack_associations_paginator: DescribeUserStackAssociationsPaginator = client.get_paginator("describe_user_stack_associations")
describe_users_paginator: DescribeUsersPaginator = client.get_paginator("describe_users")
list_associated_fleets_paginator: ListAssociatedFleetsPaginator = client.get_paginator("list_associated_fleets")
list_associated_stacks_paginator: ListAssociatedStacksPaginator = client.get_paginator("list_associated_stacks")
```


### Waiters annotations

`mypy_boto3_appstream.waiter` module contains type annotations for all waiters.

```python

client: AppStreamClient = boto3.client("appstream")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
fleet_started_waiter: FleetStartedWaiter = client.get_waiter("fleet_started")
fleet_stopped_waiter: FleetStoppedWaiter = client.get_waiter("fleet_stopped")
```





### Typed dictionations

`mypy_boto3_appstream.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> AccessEndpointTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_appstream` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("appstream")

session_client = boto3.Session().client("appstream")
```
